@@ -1,9 +1,13 @@
 library("testthat")
+setwd(tempdir())
 
 ### read and reload write some DSCs (see if Cpp serialization works)
 set.seed(0)
 stream <- DSD_Gaussians(k = 3, noise = 0.05)
 
+######################################################################
+context("DSC_DBSTREAM")
+
 # create clusterer with r = 0.05
 dbstream <- DSC_DBSTREAM(r = .05)
 update(dbstream, stream, 10000)
@@ -13,7 +17,12 @@ saveDSC(dbstream, file="dbstream.Rds")
 db <- readDSC("dbstream.Rds")
 db
 
-# Two-Stage cluster
+# cleanup
+unlink("dbstream.Rds")
+
+######################################################################
+context("DSC_TwoStage")
+
 dbstream <- DSC_TwoStage(micro=DSC_DBSTREAM(r = .05), 
 			  macro = DSC_Kmeans(k=3))
 update(dbstream, stream, 10000)
@@ -31,6 +40,8 @@ saveDSC(dstream, file="dstream.Rds")
 db <- readDSC("dstream.Rds")
 db
 
+# cleanup
+unlink(c("dbstream.Rds", "dstream.Rds"))
 
 
 
